@@ -10,14 +10,14 @@ use Tie::IxHash;
 use vars qw($VERSION $DEBUG @ISA $me);
 
 @ISA = qw(Business::OnlinePayment::AuthorizeNet Business::OnlinePayment::HTTPS);
-$VERSION = '0.02';
+$VERSION = '0.01';
 $DEBUG = 0;
 $me='Business::OnlinePayment::AuthorizeNet::ARB';
 
 sub set_defaults {
     my $self = shift;
 
-    $self->server('api2.authorize.net') unless $self->server;
+    $self->server('api.authorize.net') unless $self->server;
     $self->port('443') unless $self->port;
     $self->path('/xml/v1/request.api') unless $self->path;
 
@@ -39,7 +39,7 @@ sub map_fields {
                    'cancel recurring authorization'
                       => 'ARBCancelSubscriptionRequest',
                   );
-    $content{'action'} = $actions{lc($content{'action'} || '')} || $content{'action'};
+    $content{'action'} = $actions{lc($content{'action'})} || $content{'action'};
 
     # TYPE MAP
     my %types = ('visa'               => 'CC',
@@ -48,7 +48,7 @@ sub map_fields {
                  'discover'           => 'CC',
                  'check'              => 'ECHECK',
                 );
-    $content{'type'} = $types{lc($content{'type'} || '')} || $content{'type'};
+    $content{'type'} = $types{lc($content{'type'})} || $content{'type'};
     $self->transaction_type($content{'type'});
 
     # ACCOUNT TYPE MAP
@@ -57,7 +57,7 @@ sub map_fields {
                          'business checking'   => 'businessChecking',
                          'business savings'    => 'savings',
                         );
-    $content{'account_type'} = $account_types{lc($content{'account_type'} || '')}
+    $content{'account_type'} = $account_types{lc($content{'account_type'})}
                                || $content{'account_type'};
 
     # MASSAGE EXPIRATION 
@@ -162,6 +162,7 @@ sub submit {
                           startDate        => 'start',
                           totalOccurrences => 'periods',
                           trialOccurrences => 'trialperiods',
+                          phoneNumber      => 'phone',
                         );
 
   tie my %account, 'Tie::IxHash', ( 
@@ -240,7 +241,6 @@ sub submit {
 
   tie my %sub, 'Tie::IxHash',
     $self->revmap_fields(
-                          name            => 'subscription_name',
                           paymentSchedule => \%schedule,
                           amount          => 'amount',
                           trialAmount     => 'trialamount',
